library(readxl)
#______________________________________________________________________________
# load data ----
#______________________________________________________________________________
df = read_excel("../data/prolif_ebos.xlsx")
df
time  = df$day
time
nb    = df$replicate_1
lognb = log(nb)
lognb
#______________________________________________________________________________
# linear regression ----
#______________________________________________________________________________
# building the M matrix
M = cbind(rep(1, length((time))), time)
M
# building the A matrix for linear regression
A = t(M)%*%M
# solve linear system
theta_ls = solve(A, t(M)%*%lognb)
theta_ls[2]
doubling_time = log(2)/theta_ls[2]*24
doubling_time
#______________________________________________________________________________
# plot ----
#______________________________________________________________________________
xplot   = seq(from=0, to=4, by=0.1)
yplot_ls = theta_ls[1] + theta_ls[2]*xplot
plot(time[1:4], lognb[1:4],
     xlab="Time (d)",
     ylab="Log(number of cells)",
     cex=2,
     cex.lab=2,          # size of axis labels
     cex.axis=1.5,       # size of axis tick labels
     font=2,
     font.lab=2,
     pch=19,             # filled circle
     ylim = c(10, 14),
     xlim=c(0,4)
)
lines(xplot, yplot_ls, col="red", lwd=3, ylim=c(10, 14))
#______________________________________________________________________________
# standard errors and confidence interval ----
#______________________________________________________________________________
# estimate of sigma
n              = length(lognb)
n
p              = length(theta_ls)
p
norm_residuals = sum((lognb - M%*%theta_ls)^2)
norm_residuals
s2             = 1/(n-p)*norm_residuals
s              = sqrt(s2)
s
# se of the parameters
var = s2*matlib::inv(t(M)%*%M)
se1 = sqrt(diag(var)[1])
se1
theta_ls[1]
rse1 = se1/theta_ls[1]
rse1*100

se2 = diag(var)[2]
se2
theta_ls[2]
rse2 = se2/theta_ls[2]
rse2
rse2*100
# confidence intervals
alpha    = 0.05
t        = qt(alpha/2, df = n-p, lower.tail = FALSE)
low_95_2 = theta_ls[2] - t*se2
upper_95_2 = theta_ls[2] + t*se2
log(2)/upper_95_2*24
log(2)/theta_ls[2]*24
log(2)/low_95_2*24
